==> apache-mahout-distribution-0.11.1-src.tar.gz: apache-mahout-distribution-0.11.1/math-scala/src/main/scala/org/apache/mahout/math/drm/logical/OpMapBlock.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.mahout.math.drm.logical

import scala.reflect.ClassTag
import org.apache.mahout.math.scalabindings._
import RLikeOps._
import org.apache.mahout.math.drm.{BlockMapFunc, DrmLike}
import scala.util.Random

case class OpMapBlock[S: ClassTag, R: ClassTag](
    override var A: DrmLike[S],
    val bmf: BlockMapFunc[S, R],
    val _ncol: Int = -1,
    val _nrow: Long = -1,
    identicallyPartitioned:Boolean
    ) extends AbstractUnaryOp[S, R] {

  override protected[mahout] lazy val partitioningTag: Long =
    if (identicallyPartitioned) A.partitioningTag else Random.nextLong()

  /** R-like syntax for number of rows. */
  def nrow: Long = if (_nrow >= 0) _nrow else A.nrow

  /** R-like syntax for number of columns */
  def ncol: Int = if (_ncol >= 0) _ncol else A.ncol

}

==> apache-mahout-distribution-0.13.0-src.tar.gz: apache-mahout-distribution-0.13.0/math-scala/src/main/scala/org/apache/mahout/math/drm/logical/OpMapBlock.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.mahout.math.drm.logical

import org.apache.mahout.math.drm.{BlockMapFunc, DrmLike}

import scala.reflect.{ClassTag, classTag}
import scala.util.Random

case class OpMapBlock[S, R: ClassTag](
    override var A: DrmLike[S],
    val bmf: BlockMapFunc[S, R],
    val _ncol: Int = -1,
    val _nrow: Long = -1,
    identicallyPartitioned:Boolean
    ) extends AbstractUnaryOp[S, R] {

  override protected[mahout] lazy val partitioningTag: Long =
    if (identicallyPartitioned) A.partitioningTag else Random.nextLong()

  /**
    * Explicit extraction of key class Tag since traits don't support context bound access; but actual
    * implementation knows it
    */
  override def keyClassTag = classTag[R]

  /** R-like syntax for number of rows. */
  def nrow: Long = if (_nrow >= 0) _nrow else A.nrow

  /** R-like syntax for number of columns */
  def ncol: Int = if (_ncol >= 0) _ncol else A.ncol

}
